# Why

We at sail.black needed a package to draft microservices fast and reliably

# What

This is a modelling kit automatizing the first setp the MLOps value pipeline
for a given dataset. The perspective is not algorithm specific but rather 
dataset specific. In the end data creates value. The package shall help findin the best treatment for a given dataset fast. 

Automatizing rapid prototyping for environmental degradation modelling and other endpoints. 

The package merges CADD and Environmental Sciences. 

The software Pattern is as follows: 

![SOLID Pattern](solid_pattern_white.png)

And follow solid principles

A primer of what the synthesis of Environmental Sciences and CADD can bring

![Distribution Dataset](tests/plots/plots.png)


# Chembee
Data processing for chemistry and drug design

# Install 
```
pip install chembee
```

# Visuals 
Get to know your data with especially polar charts. 

# Example Biodegradability
## Is 
![Polar Chart](tests/plots/BiodegPolar.png)
## Is Not 
![Polar Chart](tests/plots/NBiodegPolar.png)

Aha! We have a relation to drug design here. 


# References 

1. Ruiz-Moreno, A. J., Reyes-Romero, A., Dömling, A., & Velasco-Velázquez, M. A. (2021). In silico design and selection of new tetrahydroisoquinoline-based CD44 antagonist candidates. Molecules (Basel, Switzerland), 26(7), 1877.
2. Lunghini F, Marcou G, Gantzer P, Azam P, Horvath D, Van Miert E, Varnek A. 2020 Modelling of ready biodegradability based on combined public and industrial data sources. SAR QSAR Environ. Res. 31, 171–186. (doi:10.1080/1062936X.2019.1697360)
3. Elsayad AM, Nassef AM, Al-Dhaifallah M, Elsayad KA. 2020 Classification of biodegradable substances using balanced random trees and boosted c5.0 decision trees. Int. J. Environ. Res. Public Health 17, 1–22. (doi:10.3390/ijerph17249322)

# How to cite

Before there is a publication, you can always cite the Git. 



